@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: DemoEnding.h,v 1.6 2009/09/12 19:48:08 bowkenken Exp $
+* $Id: DemoEnding.h,v 1.8 2010/01/13 09:51:37 bowkenken Exp $
 ***************************************************************/
 
 #ifndef DEMO_ENDING_H
@@ -74,11 +74,8 @@ private:
 
 	// ˥Ѻɸ
 	long len;
-	long w, h;
+	long x_dot, y_dot;
 	long baseX[EPILOGUE_LINE_MAX_N];
-	long baseY[EPILOGUE_LINE_MAX_N];
-	long mx[EPILOGUE_LINE_MAX_N][EPILOGUE_MAX_LEN];
-	long my[EPILOGUE_LINE_MAX_N][EPILOGUE_MAX_LEN];
 	long x[EPILOGUE_LINE_MAX_N][EPILOGUE_MAX_LEN];
 	long y[EPILOGUE_LINE_MAX_N][EPILOGUE_MAX_LEN];
 
