@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GameMusic.h,v 1.15 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: GameMusic.h,v 1.16 2010/02/23 16:48:05 bowkenken Exp $
 ***************************************************************/
 
 #ifndef GAME_MUSIC_H
@@ -73,6 +73,11 @@ private:
 	Mix_Music *music;
 #endif
 
+	int audioRate;
+	unsigned short audioFormat;
+	int audioChannels;
+	int audioBuffers;
+
 	music_kind_t currentKind;
 	music_kind_t prevKind;
 	long currentIdx;
