@@ -1,7 +1,6 @@
-
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2010 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -26,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GameSound.cpp,v 1.7 2009/05/31 07:23:56 bowkenken Exp $
+* $Id: GameSound.cpp,v 1.9 2010/01/07 07:22:37 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -248,6 +247,10 @@ void GameSound::init()
 	initLsSound( &lsItemSmoke,
 			"item/smoke/" );
 #endif
+
+	// 
+
+	setVolume( get_sound_volume_rate() );
 }
 
 ////////////////////////////////////////////////////////////////
@@ -399,6 +402,17 @@ void GameSound::freeLsSound( LsSound *ls )
 #endif
 }
 
+////////////////////////////////////////////////////////////////
+// SE β̤
+////////////////////////////////////////////////////////////////
+
+void GameSound::setVolume( rate_t rate )
+{
+#ifdef	HAVE_SDL_SDL_MIXER_H
+	Mix_Volume( -1, MIX_MAX_VOLUME * rate / _100_PERCENT );
+#endif
+}
+
 ////////////////////////////////////////////////////////////////
 // SE κ
 // sound_kind_t kind : SE μ
