@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: MouseMap.cpp,v 1.42 2010/01/07 07:22:37 bowkenken Exp $
+* $Id: MouseMap.cpp,v 1.43 2010/05/10 15:31:55 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -37,6 +37,13 @@
 
 ////////////////////////////////////////////////////////////////
 
+//ޥۥΥˡ
+// 1 : 
+// 0 : ľܥ
+#define	FLAG_KEY_SCROLL	0
+
+////////////////////////////////////////////////////////////////
+
 #ifdef D_WS
 extern WSCwindow* MenuWin;
 extern WSCvscrBar *MapScrollX;
@@ -676,6 +683,8 @@ void funcMotionScroll(
 	long nCurX, long nCurY
 )
 {
+	const long scrollMax = 1;
+
 	MouseMotion::ScrollKind dir = (MouseMotion::ScrollKind)m;
 
 	if( dir < MouseMotion::nScrollKindMinN )
@@ -690,24 +699,49 @@ void funcMotionScroll(
 	if( chk_executing_menu() )
 		return;
 
-	switch( dir ){
-	case MouseMotion::nScrollLeft:
-		gKey.setString( ":/misc/cursor/cursor/scroll/west\n" );
-		break;
-	case MouseMotion::nScrollRight:
-		gKey.setString( ":/misc/cursor/cursor/scroll/east\n" );
-		break;
-	case MouseMotion::nScrollUp:
-		gKey.setString( ":/misc/cursor/cursor/scroll/north\n" );
-		break;
-	case MouseMotion::nScrollDown:
-		gKey.setString( ":/misc/cursor/cursor/scroll/south\n" );
-		break;
-	default:
-		break;
+#if	FLAG_KEY_SCROLL
+	for( long i = 0; i < scrollMax; i++) {
+		switch( dir ){
+		case MouseMotion::nScrollLeft:
+			gKey.setString( ":/misc/cursor/cursor/scroll/"
+					"west\n" );
+			break;
+		case MouseMotion::nScrollRight:
+			gKey.setString( ":/misc/cursor/cursor/scroll/"
+					"east\n" );
+			break;
+		case MouseMotion::nScrollUp:
+			gKey.setString( ":/misc/cursor/cursor/scroll/"
+					"north\n" );
+			break;
+		case MouseMotion::nScrollDown:
+			gKey.setString( ":/misc/cursor/cursor/scroll/"
+					"south\n" );
+			break;
+		default:
+			break;
+		}
 	}
 
 	gKey.setString( "|" );
+#else
+		switch( dir ){
+		case MouseMotion::nScrollLeft:
+			gPcgDun.scrollTileRel( -1 * scrollMax, +-0 );
+			break;
+		case MouseMotion::nScrollRight:
+			gPcgDun.scrollTileRel( +1 * scrollMax, +-0 );
+			break;
+		case MouseMotion::nScrollUp:
+			gPcgDun.scrollTileRel( +-0, -1 * scrollMax );
+			break;
+		case MouseMotion::nScrollDown:
+			gPcgDun.scrollTileRel( +-0, +1 * scrollMax );
+			break;
+		default:
+			break;
+		}
+#endif
 }
 
 ////////////////////////////////////////////////////////////////
