@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: amenu.h,v 1.19 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: amenu.h,v 1.21 2010/05/29 12:09:03 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	AMENU_H
@@ -38,7 +38,9 @@
 /* ưޡκ */
 #define	AUTO_MARK_N_PER_PAGE	10
 #define	AUTO_MARK_PAGE_N	5
-#define	AUTO_MARK_MAX_N	(AUTO_MARK_N_PER_PAGE * AUTO_MARK_PAGE_N)
+#define	AUTO_MARK_MAX_N	\
+	((AUTO_MARK_N_PER_PAGE * AUTO_MARK_PAGE_N) \
+	+ (DFLT_AUTO_MARK_MAX_N - 1))
 
 /* ȥκʸ */
 #define	MSG_TTL_AUTO_MARK_MAX_LEN	64
@@ -144,6 +146,41 @@ typedef enum {
 	AUTO_MARK_COND_MP_MAX,
 } auto_mark_cond_t;
 
+/***************************************************************
+* ǥեȤμưޡμ
+***************************************************************/
+
+typedef enum {
+	DFLT_AUTO_MARK_NULL,
+
+	/* Ʈ(ɲ) */
+	DFLT_AUTO_MARK_FIGHT,
+	/* Ʈ() */
+	DFLT_AUTO_MARK_FIGHT_PRIO,
+
+	/* ܶƮ(ɲ) */
+	DFLT_AUTO_MARK_FIGHT_NO_THROW,
+	/* ܶƮ() */
+	DFLT_AUTO_MARK_FIGHT_NO_THROW_PRIO,
+
+	/* (ɲ) */
+	DFLT_AUTO_MARK_FIGHT_ALL,
+	/* () */
+	DFLT_AUTO_MARK_FIGHT_ALL_PRIO,
+
+	/* ƤΥƥ */
+	DFLT_AUTO_MARK_ITEM_ALL,
+	/* äƤ륢ƥ */
+	DFLT_AUTO_MARK_ITEM_OWN,
+
+	/*  */
+	DFLT_AUTO_MARK_RETREAT,
+	/*  */
+	DFLT_AUTO_MARK_CLEAR,
+
+	DFLT_AUTO_MARK_MAX_N,
+} dflt_auto_mark_t;
+
 /***************************************************************
 * ưޡ
 ***************************************************************/
@@ -155,6 +192,8 @@ typedef struct {
 	auto_mark_cond_t	cond;
 	char	macro[MACRO_MAX_LEN + 1];
 	unsigned long	flg;
+
+	dflt_auto_mark_t	dflt;
 } auto_mark_t;
 
 #endif	/* AMENU_H */
