@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gf-conf.c,v 1.29 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: gf-conf.c,v 1.31 2010/05/16 19:34:20 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -70,7 +70,7 @@ bool_t	load_game_conf( void )
 
 	/* СΥå */
 
-	if( !chk_ver_old( &ver,
+	if( chk_ver_new( &ver,
 			GAME_CONF_VER_MJR,
 			GAME_CONF_VER_MNR,
 			GAME_CONF_VER_PAT ) ){
@@ -100,7 +100,7 @@ bool_t	load_game_conf( void )
 
 	/* Сʥå */
 
-	if( chk_ver_old( &ver, 1, 0, 14 ) )
+	if( chk_ver_old( &ver, 1, 0, 15 ) )
 		ver_up_game_conf_1_0_15();
 
 	/* ե򥯥 */
@@ -451,6 +451,9 @@ bool_t	load_game_conf_set_val(
 	} else if( strcmp( id, "attribute_bold" ) == 0 ){
 		return load_game_conf_attribute_bold( id, val );
 
+	} else if( strcmp( id, "audio_buffer_size" ) == 0 ){
+		return load_game_conf_audio_buf_siz( id, val );
+
 	} else if( strcmp( id, "gnome" ) == 0 ){
 		return load_game_conf_gnome( id, val );
 
@@ -945,10 +948,24 @@ bool_t	load_game_conf_joystick_number( char *id, long val )
 	return TRUE;
 }
 
+/***************************************************************
+* եβХåե
+* char *id : ̻
+* long val : Хåե
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	load_game_conf_audio_buf_siz( char *id, long val )
+{
+	g_audio_buf_siz = val;
+
+	return TRUE;
+}
+
 /***************************************************************
 * ե GNOME 
 * char *id : ̻
-* long val : ɸޤϥ
+* long val : ɥޥ͡㤬 GNOME ?
 * return : 顼̵ä?
 ***************************************************************/
 
@@ -1511,7 +1528,7 @@ bool_t	load_game_data_cnf( long n )
 
 	/* СΥå */
 
-	if( !chk_ver_old( &ver,
+	if( chk_ver_new( &ver,
 			GAME_DATA_VER_MJR,
 			GAME_DATA_VER_MNR,
 			GAME_DATA_VER_PAT ) ){
@@ -1550,19 +1567,19 @@ bool_t	load_game_data_cnf( long n )
 
 	/* Сʥå */
 
-	if( chk_ver_old( &ver, 1, 0, 3 ) )
+	if( chk_ver_old( &ver, 1, 0, 4 ) )
 		ver_up_game_data_1_0_4();
 
-	if( chk_ver_old( &ver, 1, 1, 0 ) )
+	if( chk_ver_old( &ver, 1, 1, 1 ) )
 		ver_up_game_data_1_1_1();
 
-	if( chk_ver_old( &ver, 1, 1, 2 ) )
+	if( chk_ver_old( &ver, 1, 1, 3 ) )
 		ver_up_game_data_1_1_3();
 
-	if( chk_ver_old( &ver, 1, 2, 11 ) )
+	if( chk_ver_old( &ver, 1, 2, 12 ) )
 		ver_up_game_data_1_2_12();
 
-	if( chk_ver_old( &ver, 1, 2, 21 ) )
+	if( chk_ver_old( &ver, 1, 2, 22 ) )
 		ver_up_game_data_cnf_1_2_22();
 
 	/* եΥ */
@@ -1971,6 +1988,7 @@ bool_t	save_game_conf_contents( FILE *fp, const ver_t *ver )
 	flg_err |= !save_game_conf_screen_size( fp, ver );
 	flg_err |= !save_game_conf_scroll( fp, ver );
 	flg_err |= !save_game_conf_flg( fp, ver );
+	flg_err |= !save_game_conf_audio_buf_siz( fp, ver );
 	flg_err |= !save_game_conf_gnome( fp, ver );
 	flg_err |= !save_game_conf_set_window_position( fp, ver );
 	flg_err |= !save_game_conf_win_pos( fp, ver );
@@ -2150,6 +2168,23 @@ bool_t	save_game_conf_flg( FILE *fp, const ver_t *ver )
 	return TRUE;
 }
 
+/***************************************************************
+* եβХåեΥ
+* FILE *fp : ե
+* const ver_t *ver : եΥС
+* return : 顼̵ä?
+***************************************************************/
+
+bool_t	save_game_conf_audio_buf_siz( FILE *fp, const ver_t *ver )
+{
+	fprintf( fp, "\n" );
+	fprintf( fp, "# audio buffer size\n" );
+	fprintf( fp, "audio_buffer_size = %ld\n",
+			(long)g_audio_buf_siz );
+
+	return TRUE;
+}
+
 /***************************************************************
 * եΥɥ֤ե饰Υ
 * FILE *fp : ե
