@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: tmenu-tab.h,v 1.30 2010/01/07 07:12:21 bowkenken Exp $
+* $Id: tmenu-tab.h,v 1.31 2010/05/19 00:32:53 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	TMENU_TAB_H
@@ -217,6 +217,16 @@ menu_t	ls_menu_magic_guild[] = {
 		FLG_NULL,
 	},
 
+	{
+		"/magic guild/MAG/short_teleport_party",
+		"<Branch>",
+		'\0',
+		"",
+		N_MSG_SPELL_SHORT_TELEPORT_PARTY, "",
+		cb_menu_magic_guild, (void *)SPELL_KIND_SHORT_TELEPORT_PARTY,
+		FLG_NULL,
+	},
+
 	{
 		"/magic guild/MAG/teleport_party",
 		"<Branch>",
